<?php
/**
 * @package         CDN for Joomla!
 * @version         6.6.3PRO
 * 
 * @author          Peter van Westen <info@regularlabs.com>
 * @link            http://regularlabs.com
 * @copyright       Copyright © 2023 Regular Labs All Rights Reserved
 * @license         http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 */

defined('_JEXEC') or die;

use Joomla\CMS\Factory as JFactory;
use Joomla\CMS\Language\Text as JText;
use RegularLabs\Library\Document as RL_Document;
use RegularLabs\Library\Extension as RL_Extension;
use RegularLabs\Library\SystemPlugin as RL_SystemPlugin;
use RegularLabs\Plugin\System\CDNForJoomla\Replace;

// Do not instantiate plugin on install pages
// to prevent installation/update breaking because of potential breaking changes
$input = JFactory::getApplication()->input;
if (in_array($input->get('option'), ['com_installer', 'com_regularlabsmanager']) && $input->get('action') != '')
{
    return;
}

if ( ! is_file(__DIR__ . '/vendor/autoload.php'))
{
    return;
}

require_once __DIR__ . '/vendor/autoload.php';

if ( ! is_file(JPATH_LIBRARIES . '/regularlabs/autoload.php')
    || ! is_file(JPATH_LIBRARIES . '/regularlabs/src/SystemPlugin.php')
)
{
    JFactory::getLanguage()->load('plg_system_cdnforjoomla', __DIR__);
    JFactory::getApplication()->enqueueMessage(
        JText::sprintf('CDN_EXTENSION_CAN_NOT_FUNCTION', JText::_('CDNFORJOOMLA'))
        . ' ' . JText::_('CDN_REGULAR_LABS_LIBRARY_NOT_INSTALLED'),
        'error'
    );

    return;
}

require_once JPATH_LIBRARIES . '/regularlabs/autoload.php';

if ( ! RL_Document::isJoomlaVersion(3, 'CDNFORJOOMLA'))
{
    RL_Extension::disable('cdnforjoomla', 'plugin');

    RL_Document::adminError(
        JText::sprintf('RL_PLUGIN_HAS_BEEN_DISABLED', JText::_('CDNFORJOOMLA'))
    );

    return;
}

if (true)
{
    class PlgSystemCDNForJoomla extends RL_SystemPlugin
    {
        public $_lang_prefix = 'CDN';
        public $_page_types  = ['html', 'feed', 'ajax', 'json', 'raw'];
        public $_jversion    = 3;

        protected function changeFinalHtmlOutput(&$html)
        {
            Replace::replace($html);

            return true;
        }

        protected function cleanFinalHtmlOutput(&$html)
        {
            $html = str_replace(['{nocdn}', '{/nocdn}'], '', $html);
        }
    }
}
