<?php
/**
 * @package         CDN for Joomla!
 * @version         6.6.3PRO
 * 
 * @author          Peter van Westen <info@regularlabs.com>
 * @link            http://regularlabs.com
 * @copyright       Copyright © 2023 Regular Labs All Rights Reserved
 * @license         http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 */

defined('_JEXEC') or die;

use Joomla\CMS\Factory as JFactory;

class PlgSystemCDNForJoomlaInstallerScript
{
    public function postflight($install_type, $adapter)
    {
        if ( ! in_array($install_type, ['install', 'update']))
        {
            return true;
        }

        self::fixOldParams();

        return true;
    }

    private static function fixFieldTypes(&$params, $setid)
    {
        if ( ! isset($params->{'filetypes' . $setid}))
        {
            return;
        }

        $filetypes = $params->{'filetypes' . $setid};

        if (is_array($filetypes))
        {
            $filetypes = array_diff($filetypes, ['x']);
            $filetypes = implode(',', $filetypes);
        }

        if ($filetypes == '*')
        {
            $filetypes = 'css,js,bmp,gif,jpg,jpeg,ico,png,tif,tiff,svg,doc,docx,odt,pdf,rtf,txt';
        }

        $filetypes = str_replace('-', ',', $filetypes);

        if (isset($params->{'extratypes' . $setid}))
        {
            $filetypes .= ',' . $params->{'extratypes' . $setid};
            unset($params->{'extratypes' . $setid});
        }

        $params->{'filetypes' . $setid} = $filetypes;
    }

    /**
     * Fixes old params from before v4.1.0
     */
    private static function fixOldParams()
    {
        $db = JFactory::getDbo();

        $query = $db->getQuery(true)
            ->select($db->quoteName('extension_id'))
            ->select($db->quoteName('params'))
            ->from('#__extensions')
            ->where($db->quoteName('element') . ' = ' . $db->quote('cdnforjoomla'))
            ->where($db->quoteName('type') . ' = ' . $db->quote('plugin'))
            ->where($db->quoteName('folder') . ' = ' . $db->quote('system'));
        $db->setQuery($query);

        $plugin = $db->loadObject();

        if (empty($plugin) || empty($plugin->params))
        {
            return;
        }

        $params = json_decode($plugin->params);

        if (empty($params))
        {
            return;
        }

        // The new web protocol setting is found, so no need to do anything
        if (isset($params->web_protocol))
        {
            return;
        }

        for ($i = 1; $i <= 5; $i++)
        {
            $setid = ($i <= 1) ? '' : '_' . (int) $i;

            self::fixFieldTypes($params, $setid);
            self::fixProtocol($params, $setid);
        }

        $params = json_encode($params);

        // Nothing has changed
        if ($params == $plugin->params)
        {
            return;
        }

        $query->clear()
            ->update('#__extensions')
            ->set($db->quoteName('params') . ' = ' . $db->quote($params))
            ->where($db->quoteName('extension_id') . ' = ' . $db->quote($plugin->extension_id));
        $db->setQuery($query);
        $db->execute();
    }

    private static function fixProtocol(&$params, $setid)
    {
        if ( ! isset($params->{'enable_https' . $setid}))
        {
            return;
        }

        switch ($params->{'enable_https' . $setid})
        {
            case 2:
                $protocol = 'https';
                break;

            case 0:
                $protocol = 'http';
                break;

            case 1:
            default:
                $protocol = 'both';
                break;
        }

        $params->{'web_protocol' . $setid} = $protocol;
        unset($params->{'enable_https' . $setid});
    }
}
